agentle.agents.a2a.tasks.task
=============================

.. automodule:: agentle.agents.a2a.tasks.task

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      Any
      Artifact
      BaseModel
      Message
      Sequence
      Task
      TaskState
   